pilas.actores.pelota

Package pilas :: Package actores :: Module pelota |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.pelota

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10  import pilas
    11
    12 -class Pelota(Actor):
    13      """Representa una pelota de Volley, que puede rebotar e interactuar con la física del escenario."""
    14
    15 -    def __init__(self, x=0, y=0):
    16          """Construye una pelota y define la posición inicial.
    17
    18          :param x: Posición horizontal inicial.
    19          :param y: posición vertical inicial.
    20          """
    21          imagen = pilas.imagenes.cargar('pelota.png')
    22          Actor.__init__(self, imagen)
    23          self.rotacion = 0
    24          self.x = x
    25          self.y = y
    26          self.radio_de_colision = 25
    27
    28          self.aprender(pilas.habilidades.RebotarComoPelota)
    29